@@ -1,5 +1,4 @@
 import requests
-import json
 from .environment import Environment
 from typing import List
 
@@ -11,6 +10,7 @@ class Db(object):
 
     def insert(self, data: dict) -> bool | None:
         url = f"{self.env.LOG_API_BASE_URL}/remote-cache/db"
+        print(f"DB URL: {url}")
         headers = {
             "Authorization": f"Bearer {self.env.LOG_API_TOKEN}",
             "Content-Type": "application/json"
@@ -27,9 +27,10 @@ class Db(object):
         if response.status_code == 200:
             return True
         else:
+            print(f"Error: {response.text} - {response.status_code}")
             return None
 
-    def find(self, filters: dict) -> List[dict] | None:
+    def find(self, filters: dict | List[dict]) -> List[dict] | None:
         url = f"{self.env.LOG_API_BASE_URL}/remote-cache/db"
         headers = {
             "Authorization": f"Bearer {self.env.LOG_API_TOKEN}"
